<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\channel;
use App\Models\Client;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Artisan;
use Illuminate\Support\Facades\Session;
use Illuminate\Support\Facades\Storage;
use Spatie\Backup\Commands\BackupCommand;

class ChannelController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = getInformationData('channel');
        return view('admin.channels.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        try {
            channel::create([
                'user_id' => auth('web')->check() ?  getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ?  getUserType() : null,
                'name' => $request->name,
                'number_id' => $request->number_id,
                'token' => $request->token,
                'version' => $request->version,
            ]);
            Session::flash('message', 'تم الحفظ بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->back();
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        try {
            channel::findorfail($request->id)->update([
                'user_id' => auth('web')->check() ?  getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ?  getUserType() : null,
                'name' => $request->name,
                'number_id' => $request->number_id,
                'token' => $request->token,
                'version' => $request->version,
            ]);
            Session::flash('message', 'تم التعديل بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->back();
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request)
    {
        try {
            channel::destroy($request->id);
            Session::flash('message', 'تم الحذف بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->back();
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function channels_messages($id_cahnel)
    {
        $data = Client::whereNotNull('channel_id')->where('channel_id',$id_cahnel)->orderByDesc('uuid')->get();
        return view('admin.channels.chats',compact('data','id_cahnel'));
    }
    public function get_channels_messages($id,$id_cahnel)
    {
        $data_messages = Client::findorfail($id);
        $data_messages->messages()->update([
            "status"=> 'read'
        ]);

        $data = Client::whereNotNull('channel_id')->where('channel_id',$id_cahnel)->get();
        return view('admin.channels.chats',compact('data_messages','data','id_cahnel'));
    }


    // public function backup()
    // {
    //     try {
    //         $backupFileName = 'backup_' . request()->getHost() . '-' . date('Y-m-d_H-i-s') . '.sql';
    //         $backupFilePath = storage_path('app/backups/') . $backupFileName;

    //         if (!is_dir(storage_path('app/backups'))) {
    //             mkdir(storage_path('app/backups'), 0755, true);
    //         }

    //         $command = "mysqldump --user=" . config('database.connections.mysql.username') .
    //             " --password=" . config('database.connections.mysql.password') .
    //             " --host=" . config('database.connections.mysql.host') .
    //             " " . config('database.connections.mysql.database') .
    //             " > $backupFilePath";

    //         exec($command);
    //     } catch (\Exception $e) {
    //         // تعامل مع الخطأ هنا إذا كنت ترغب
    //     }

    //     Session::flash('message', 'تم إنشاء النسخة الاحتياطية بنجاح');
    //     Session::flash('alert-class', 'alert-success');

    //     return response()->download($backupFilePath)->deleteFileAfterSend(true);
    // }

    
public function backup()
{
       Artisan::call('db:backup');
}


    


    public function Explanations()
    {
        return view('admin.Explanations.index');
    }

}
