<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\BootList;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;

class ListBootController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = getInformationData('BootList');
        return view('admin.listboot.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.listboot.create');
    }

    /**
     * Store a newly created resource in storag = $request->e.
     */
    public function store(Request $request)
    {
        try {
            BootList::create([
                'user_id' => auth('web')->check() ?  getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ?  getUserType() : null,
                'name'=> $request->name,
                'header_text' => $request->header_text,
                'body_text' => $request->body_text,
                'footer_text' => $request->footer_text,
                'button_text' => $request->button_text,
                'section_1_title' => $request->section_1_title,
            ]);
            Session::flash('message', 'تم الحفظ بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('listBoot.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $data = BootList::findorfail($id);
        return view('admin.listboot.ReplyList.index',compact('data'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data = BootList::findorfail($id);
        return view('admin.listboot.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        try {
            $data = BootList::findorfail($request->id);
            BootList::findorfail($request->id)->update([
                'user_id' => $data->user_id,
                'subscriber_id' => $data->subscriber_id,
                'name'=> $request->name,
                'header_text' => $request->header_text,
                'body_text' => $request->body_text,
                'footer_text' => $request->footer_text,
                'button_text' => $request->button_text,
                'section_1_title' => $request->section_1_title,
            ]);
            Session::flash('message', 'تم التعديل بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('listBoot.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        try {
            BootList::destroy(\request()->id);
            Session::flash('message', 'تم الحذف بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('listBoot.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }
}
