<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\subscriber;
use Carbon\Carbon;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;

class SubscriptionController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = subscriber::all();
        return view('admin.subscription.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.subscription.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {

        $request->validate([
            'email' => 'required|email|unique:subscribers,email'
        ]);
        if ($request->type_subscribers == "years") {
            $expert = Carbon::now()->addYear();
        } elseif ($request->type_subscribers == "Monthly") {
            $expert = Carbon::now()->addMonth();
        } elseif ($request->type_subscribers == "free") {
            $expert = Carbon::now()->addDays(15);
        }

        try {
            subscriber::create([
                'name' => $request->name,
                'email' => $request->email,
                'password' => Hash::make($request->password),
                'phone' => $request->phone,
                'address' => $request->address,
                'status' => "active",
                'type_subscribers' => $request->type_subscribers,
                'expiry_data' => $expert,
            ]);
            Session::flash('message', 'تم الحفظ بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('admin.subscription.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }


    }

    public function edit(string $id)
    {
        $data = subscriber::findorfail($id);
        return view('admin.subscription.edit', compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'email' => 'required|email|unique:subscribers,email,' . $request->id
        ]);
        if ($request->type_subscribers == "years") {
            $expert = Carbon::now()->addYear();
        } elseif ($request->type_subscribers == "Monthly") {
            $expert = Carbon::now()->addMonth();
        } elseif ($request->type_subscribers == "free") {
            $expert = Carbon::now()->addDays(15);
        }

        try {
            subscriber::findorfail($request->id)->update([
                'name' => $request->name,
                'email' => $request->email,
                'phone' => $request->phone,
                'address' => $request->address,
                'type_subscribers' => $request->type_subscribers,
                'expiry_data' => $expert,
            ]);
            Session::flash('message', 'تم التعديل بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('admin.subscription.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request, string $id)
    {
        try {
            subscriber::destroy($request->id);
            Session::flash('message', 'تم الحذف بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('admin.subscription.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function status_status_subscription(Request $request)
    {

        $status = $request->input('status');
        $yourModel = subscriber::find($request->id);
        $yourModel->status = $status;
        $yourModel->save();
        return response()->json(['message' => 'تم تحديث الحالة بنجاح']);
    }

    public function changePassword(Request $request)
    {
        try {
            subscriber::findorfail($request->id)->update([
                'password' => Hash::make($request->password)
            ]);
            Session::flash('message', 'تم تغير كلمه المرور بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('admin.subscription.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function renewalSubscription(Request $request)
    {
        try {
            if ($request->type_subscribers == "years") {
                $expert = Carbon::now()->addYear();
            } elseif ($request->type_subscribers == "Monthly") {
                $expert = Carbon::now()->addMonth();
            } elseif ($request->type_subscribers == "free") {
                $expert = Carbon::now()->addDays(15);
            }

            subscriber::findorfail($request->id)->update([
                'expiry_data' => $expert,
                'type_subscribers' => $request->type_subscribers
            ]);
            Session::flash('message', 'تم تجديد الاشتراك بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('admin.subscription.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }

    }
}
