<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\BootButton;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Session;

class ButtonBootController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = getInformationData('BootButton');
        return view('admin.buttonboot.index',compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.buttonboot.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        try {
            BootButton::create([
                'user_id' => auth('web')->check() ?  getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ?  getUserType() : null,
                'name'=> $request->name,
                'button_text' => $request->button_text,
            ]);
            Session::flash('message', 'تم الحفظ بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('ButtonBoot.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    /**
     * Display the specified resource.
     */
    public function show(string $id)
    {
        $data =  BootButton::findorfail($id);
        return view('admin.buttonboot.ReplyButton.index',compact('data'));
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit(string $id)
    {
        $data =  BootButton::findorfail($id);
        return view('admin.buttonboot.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        try {
            BootButton::findorfail($request->id)->update([
                'user_id' => auth('web')->check() ?  getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ?  getUserType() : null,
                'name'=> $request->name,
                'button_text' => $request->button_text,
            ]);
            Session::flash('message', 'تم التعديل بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('ButtonBoot.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(string $id)
    {
        try {
            BootButton::destroy(\request()->id);
            Session::flash('message', 'تم الحذف بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('ButtonBoot.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }
}
