<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\employee;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Session;

class EmployeeController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $data = getInformationData('employee');
        return view('admin.employee.index', compact('data'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('admin.employee.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $request->validate([
            'email' => 'required|email|unique:employees,email'
        ]);
        try {
            employee::create([
                'user_id' => auth('web')->check() ? getUserType() : null,
                'subscriber_id' => auth('subscriber')->check() ? getUserType() : null,
                'name' => $request->name,
                'email' => $request->email,
                'password' => Hash::make($request->password),
                'status' => "active",
            ]);
            Session::flash('message', 'تم الحفظ بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('employees.index');
        } catch (\Exception $exception) {

        }
    }


    public function edit(string $id)
    {
        $data = employee::findorfail($id);
        return view('admin.employee.edit',compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, string $id)
    {
        $request->validate([
            'email' => 'required|email|unique:employees,email,' . $request->id
        ]);
        try {
            $data = employee::findorfail($request->id);
            employee::findorfail($request->id)->update([
                'user_id' => $data->user_id ?? null,
                'subscriber_id' => $data->subscriber_id ?? null,
                'name' => $request->name,
                'email' => $request->email,
                'status' => "active",
            ]);
            Session::flash('message', 'تم التعديل بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('employees.index');
        } catch (\Exception $exception) {

        }
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy(Request $request, string $id)
    {
        try {
            employee::destroy($request->id);
            Session::flash('message', 'تم الحذف بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('employees.index');
        } catch (\Exception $exception) {

        }
    }

    public function changePassword(Request $request)
    {
        try {
            employee::findorfail($request->id)->update([
                'password' => Hash::make($request->password)
            ]);
            Session::flash('message', 'تم تغير كلمه المرور بنجاح');
            Session::flash('alert-class', 'alert-success');
            return redirect()->route('employees.index');
        } catch (\Exception $exception) {
            return redirect()->back()->withErrors(['error' => $exception->getMessage()]);
        }
    }

    public function status_status_employee(Request $request)
    {

        $status = $request->input('status');
        $yourModel = employee::find($request->id);
        $yourModel->status = $status;
        $yourModel->save();
        return response()->json(['message' => 'تم تحديث الحالة بنجاح']);
    }
}
