<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Http\Requests\Auth\EmployeeRequest;
use App\Providers\RouteServiceProvider;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\View\View;

class AuthenticatedEmployeeController extends Controller
{
    /**
     * Display the login view.
     */
    public function create(): View
    {
        return view('employee.auth.login');
    }

    /**
     * Handle an incoming authentication request.
     */
    public function store(EmployeeRequest $request): RedirectResponse
    {

        if (auth('employee')->attempt(['email' => $request->email, 'password' => $request->password, 'status' => "active"])) {
            $request->authenticate();

            $request->session()->regenerate();

            return redirect()->intended(RouteServiceProvider::EMPLOYEE);
        }
        return redirect()->route('employeelogin')->withErrors(['error' => 'برجاء التواصل مع المسئول']);
    }

    /**
     * Destroy an authenticated session.
     */
    public function destroy(Request $request): RedirectResponse
    {
        Auth::guard('employee')->logout();

        $request->session()->invalidate();

        $request->session()->regenerateToken();

        return redirect()->route('employeelogin');
    }
}
